==> hubzero-cms-1.2.1_1.2.1.3.orig.tar.gz: hubzero-cms-1.2.1-1.2.1.3/cms/modules/mod_resourcemenu/helper.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 * All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

/**
 * Module class for displaying a megamenu
 */
class modResourceMenu extends Hubzero_Module
{
	/**
	 * Display module content
	 * 
	 * @return     void
	 */
	public function display()
	{
		$this->moduleid    = $this->params->get('moduleid');
		$this->moduleclass = $this->params->get('moduleclass');

		// Build the HTML
		$obj = new stdClass;
		$obj->text = $this->_xHubTags($this->params->get('content'));

		JPluginHelper::importPlugin('content', 'xhubtags');
		$dispatcher = JDispatcher::getInstance();

		// Get the search result totals
		$results = $dispatcher->trigger(
			'onPrepareContent', 
			array(
				'',
				$obj,
				$this->params
			)
		);

		$this->html = $obj->text;

		// Push some CSS to the tmeplate
		ximport('Hubzero_Document');
		Hubzero_Document::addModuleStylesheet($this->module->module);
		Hubzero_Document::addModuleScript($this->module->module);

		require(JModuleHelper::getLayoutPath($this->module->module));
	}
}

==> hubzero-cms-1.2.2_1.2.2.8.orig.tar.gz: hubzero-cms-1.2.2-1.2.2.8/cms/modules/mod_resourcemenu/helper.php <==
<?php
/**
 * HUBzero CMS
 *
 * Copyright 2005-2011 Purdue University. All rights reserved.
 * All rights reserved.
 *
 * This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 *
 * The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
 * software: you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * HUBzero is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * HUBzero is a registered trademark of Purdue University.
 *
 * @package   hubzero-cms
 * @author    Shawn Rice <zooley@purdue.edu>
 * @copyright Copyright 2005-2011 Purdue University. All rights reserved.
 * @license   http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

/**
 * Module class for displaying a megamenu
 */
class modResourceMenu extends \Hubzero\Module\Module
{
	/**
	 * Display module content
	 * 
	 * @return     void
	 */
	public function display()
	{
		$this->moduleid    = $this->params->get('moduleid');
		$this->moduleclass = $this->params->get('moduleclass');

		// Build the HTML
		$obj = new stdClass;
		$obj->text = $this->_xHubTags($this->params->get('content'));

		JPluginHelper::importPlugin('content', 'xhubtags');
		$dispatcher = JDispatcher::getInstance();

		// Get the search result totals
		$results = $dispatcher->trigger(
			'onPrepareContent', 
			array(
				'',
				$obj,
				$this->params
			)
		);

		$this->html = $obj->text;

		// Push some CSS to the tmeplate
		$this->css();
		$this->js();

		require(JModuleHelper::getLayoutPath($this->module->module));
	}
}
